Package: minioclient
Title: Interface to the 'MinIO' Client
Version: 0.0.6
Authors@R: c(person(
              "Carl", "Boettiger", 
              email = "cboettig@gmail.com", 
              role = c("aut", "cre"),
              comment = c(ORCID = "0000-0002-1642-628X")),
              person(
              "Markus", "Skyttner",
              email = "markussk@kth.se",
              role = c("ctb")
              )
            )
Description: An R interface to the 'MinIO' Client. The 'MinIO' Client ('mc')
  provides a modern alternative to UNIX commands like 'ls', 'cat', 'cp',
  'mirror', 'diff', 'find' etc. It supports 'filesystems'  and Amazon "S3"
  compatible cloud storage service ("AWS" Signature v2 and v4).
  This package provides convenience functions for installing the 'MinIO'
  client and running any operations, as described in the official 
  documentation, <https://min.io/docs/minio/linux/reference/minio-mc.html?ref=docs-redirect>.
  This package provides a flexible and high-performance alternative to 'aws.s3'.
License: MIT + file LICENSE
URL: https://github.com/cboettig/minioclient,
        https://cboettig.github.io/minioclient/
BugReports: https://github.com/cboettig/minioclient/issues
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: spelling, testthat (>= 3.0.0), curl
Config/testthat/edition: 3
Imports: fs, glue, tools, utils, processx, jsonlite
Language: en-US
NeedsCompilation: no
Packaged: 2023-11-07 00:19:08 UTC; cboettig
Author: Carl Boettiger [aut, cre] (<https://orcid.org/0000-0002-1642-628X>),
  Markus Skyttner [ctb]
Maintainer: Carl Boettiger <cboettig@gmail.com>
Repository: CRAN
Date/Publication: 2023-11-07 10:10:02 UTC
Built: R 4.4.0; ; 2024-04-29 23:33:54 UTC; unix
