# Generated by roxygen2: do not edit by hand

export(install_mc)
export(mc)
export(mc_alias_ls)
export(mc_alias_set)
export(mc_anonymous_set)
export(mc_cat)
export(mc_config_set)
export(mc_cp)
export(mc_du)
export(mc_head)
export(mc_ls)
export(mc_mb)
export(mc_mirror)
export(mc_mv)
export(mc_rb)
export(mc_rm)
export(mc_sql)
